@@ -260,7 +260,11 @@ class MessageBus(BaseMessageBus):
         return await future
 
     async def introspect(
-        self, bus_name: str, path: str, timeout: float = 30.0
+        self,
+        bus_name: str,
+        path: str,
+        timeout: float = 30.0,
+        validate_property_names: bool = True,
     ) -> intr.Node:
         """Get introspection data for the node at the given path from the given
         bus name.
@@ -274,6 +278,8 @@ class MessageBus(BaseMessageBus):
         :type path: str
         :param timeout: The timeout to introspect.
         :type timeout: float
+        :param validate_property_names: Whether to validate property names or not.
+        :type validate_property_names: bool
 
         :returns: The introspection data for the name at the path.
         :rtype: :class:`Node <dbus_fast.introspection.Node>`
@@ -295,6 +301,7 @@ class MessageBus(BaseMessageBus):
             path,
             partial(self._reply_handler, future),
             check_callback_type=False,
+            validate_property_names=validate_property_names,
         )
 
         timer_handle = self._loop.call_later(
