@@ -1,5 +1,5 @@
 from functools import lru_cache
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+from typing import Any, Callable, Optional, Union
 
 from .errors import InvalidSignatureError, SignatureBodyMismatchError
 from .validators import is_object_path_valid
@@ -24,16 +24,19 @@ class SignatureType:
     __slots__ = ("token", "children", "_signature")
 
     def __init__(self, token: str) -> None:
-        self.token = token
-        self.children: List[SignatureType] = []
+        """Init a new SignatureType."""
+        self.token: str = token
+        self.children: list[SignatureType] = []
         self._signature: Optional[str] = None
 
     def __eq__(self, other: Any) -> bool:
+        """Compare this type to another type or signature string."""
         if type(other) is SignatureType:
             return self.signature == other.signature
         return super().__eq__(other)
 
     def _collapse(self) -> str:
+        """Collapse this type into a signature string."""
         if self.token not in "a({":
             return self.token
 
@@ -57,7 +60,7 @@ class SignatureType:
         return self._signature
 
     @staticmethod
-    def _parse_next(signature: str) -> Tuple["SignatureType", str]:
+    def _parse_next(signature: str) -> tuple["SignatureType", str]:
         if not signature:
             raise InvalidSignatureError("Cannot parse an empty signature")
 
@@ -255,10 +258,9 @@ class SignatureType:
                 child_type.verify(member)
 
     def _verify_struct(self, body: Any) -> None:
-        # TODO allow tuples
-        if not isinstance(body, list):
+        if not isinstance(body, (list, tuple)):
             raise SignatureBodyMismatchError(
-                f'DBus STRUCT type "(" must be Python type "list", got {type(body)}'
+                f'DBus STRUCT type "(" must be Python type "list" or "tuple", got {type(body)}'
             )
 
         if len(body) != len(self.children):
@@ -293,7 +295,7 @@ class SignatureType:
 
         return True
 
-    validators: Dict[str, Callable[["SignatureType", Any], None]] = {
+    validators: dict[str, Callable[["SignatureType", Any], None]] = {
         "y": _verify_byte,
         "b": _verify_boolean,
         "n": _verify_int16,
@@ -334,7 +336,7 @@ class SignatureTree:
     def __init__(self, signature: str = "") -> None:
         self.signature = signature
 
-        self.types: List[SignatureType] = []
+        self.types: list[SignatureType] = []
 
         if len(signature) > 0xFF:
             raise InvalidSignatureError("A signature must be less than 256 characters")
@@ -348,7 +350,7 @@ class SignatureTree:
             return self.signature == other.signature
         return super().__eq__(other)
 
-    def verify(self, body: List[Any]) -> bool:
+    def verify(self, body: list[Any]) -> bool:
         """Verifies that the give body matches this signature tree
 
         :param body: the body to verify for this tree
@@ -400,6 +402,14 @@ class Variant:
         verify: bool = True,
     ) -> None:
         """Init a new Variant."""
+        self._init_variant(signature, value, verify)
+
+    def _init_variant(
+        self,
+        signature: Union[str, SignatureTree, SignatureType],
+        value: Any,
+        verify: bool,
+    ) -> None:
         if type(signature) is SignatureTree:
             signature_tree = signature
             self.signature = signature_tree.signature
@@ -435,14 +445,12 @@ class Variant:
         )
 
 
-@lru_cache(maxsize=None)
-def get_signature_tree(signature: str) -> SignatureTree:
-    """Get a signature tree for the given signature.
+get_signature_tree = lru_cache(maxsize=None)(SignatureTree)
+"""Get a signature tree for the given signature.
 
-    :param signature: The signature to get a tree for.
-    :type signature: str
+:param signature: The signature to get a tree for.
+:type signature: str
 
-    :returns: The signature tree for the given signature.
-    :rtype: :class:`SignatureTree`
-    """
-    return SignatureTree(signature)
+:returns: The signature tree for the given signature.
+:rtype: :class:`SignatureTree`
+"""
